@@ -73,15 +73,10 @@ if (!$data['user']['is_guest']) {
 }
 
 $user_menu->addItem(
-	(new CLink(SPACE,
-		(new CUrl('index.php'))
-			->setArgument('reconnect', 1)
-			->setArgument('form', 'default')
-			->toString()
-	))
+	(new CLink(SPACE, 'javascript:;'))
 		->addClass(ZBX_STYLE_TOP_NAV_SIGNOUT)
 		->setTitle(_('Sign out'))
-		->addSID()
+		->onClick('ZABBIX.logout()')
 );
 
 $user_navigation->addItem($user_menu);
